@@ -101,7 +101,7 @@ def to_bool(val: Any) -> bool:
 
     :param val: value being converted
     :return: boolean value expressed in the passed in value
-    :raises: ValueError if the string does not contain a value corresponding to a boolean value
+    :raises ValueError: if the string does not contain a value corresponding to a boolean value
     """
     if isinstance(val, str):
         if val.capitalize() == str(True):
@@ -178,17 +178,14 @@ class Settable:
         self.completer = completer
 
     def get_value(self) -> Any:
-        """
-        Get the value of the settable attribute
-        :return:
-        """
+        """Get the value of the settable attribute."""
         return getattr(self.settable_obj, self.settable_attrib_name)
 
-    def set_value(self, value: Any) -> Any:
+    def set_value(self, value: Any) -> None:
         """
-        Set the settable attribute on the specified destination object
-        :param value: New value to set
-        :return: New value that the attribute was set to
+        Set the settable attribute on the specified destination object.
+
+        :param value: new value to set
         """
         # Run the value through its type function to handle any conversion or validation
         new_value = self.val_type(value)
@@ -205,7 +202,6 @@ class Settable:
         # Check if we need to call an onchange callback
         if orig_value != new_value and self.onchange_cb:
             self.onchange_cb(self.name, orig_value, new_value)
-        return new_value
 
 
 def is_text_file(file_path: str) -> bool:
@@ -213,7 +209,7 @@ def is_text_file(file_path: str) -> bool:
 
     :param file_path: path to the file being checked
     :return: True if the file is a non-empty text file, otherwise False
-    :raises OSError if file can't be read
+    :raises OSError: if file can't be read
     """
     import codecs
 
@@ -862,9 +858,9 @@ def align_text(
     :param truncate: if True, then each line will be shortened to fit within the display width. The truncated
                      portions are replaced by a '…' character. Defaults to False.
     :return: aligned text
-    :raises: TypeError if fill_char is more than one character (not including ANSI style sequences)
-    :raises: ValueError if text or fill_char contains an unprintable character
-    :raises: ValueError if width is less than 1
+    :raises TypeError: if fill_char is more than one character (not including ANSI style sequences)
+    :raises ValueError: if text or fill_char contains an unprintable character
+    :raises ValueError: if width is less than 1
     """
     import io
     import shutil
@@ -986,9 +982,9 @@ def align_left(
     :param truncate: if True, then text will be shortened to fit within the display width. The truncated portion is
                      replaced by a '…' character. Defaults to False.
     :return: left-aligned text
-    :raises: TypeError if fill_char is more than one character (not including ANSI style sequences)
-    :raises: ValueError if text or fill_char contains an unprintable character
-    :raises: ValueError if width is less than 1
+    :raises TypeError: if fill_char is more than one character (not including ANSI style sequences)
+    :raises ValueError: if text or fill_char contains an unprintable character
+    :raises ValueError: if width is less than 1
     """
     return align_text(text, TextAlignment.LEFT, fill_char=fill_char, width=width, tab_width=tab_width, truncate=truncate)
 
@@ -1009,9 +1005,9 @@ def align_center(
     :param truncate: if True, then text will be shortened to fit within the display width. The truncated portion is
                      replaced by a '…' character. Defaults to False.
     :return: centered text
-    :raises: TypeError if fill_char is more than one character (not including ANSI style sequences)
-    :raises: ValueError if text or fill_char contains an unprintable character
-    :raises: ValueError if width is less than 1
+    :raises TypeError: if fill_char is more than one character (not including ANSI style sequences)
+    :raises ValueError: if text or fill_char contains an unprintable character
+    :raises ValueError: if width is less than 1
     """
     return align_text(text, TextAlignment.CENTER, fill_char=fill_char, width=width, tab_width=tab_width, truncate=truncate)
 
@@ -1032,9 +1028,9 @@ def align_right(
     :param truncate: if True, then text will be shortened to fit within the display width. The truncated portion is
                      replaced by a '…' character. Defaults to False.
     :return: right-aligned text
-    :raises: TypeError if fill_char is more than one character (not including ANSI style sequences)
-    :raises: ValueError if text or fill_char contains an unprintable character
-    :raises: ValueError if width is less than 1
+    :raises TypeError: if fill_char is more than one character (not including ANSI style sequences)
+    :raises ValueError: if text or fill_char contains an unprintable character
+    :raises ValueError: if width is less than 1
     """
     return align_text(text, TextAlignment.RIGHT, fill_char=fill_char, width=width, tab_width=tab_width, truncate=truncate)
 
@@ -1057,8 +1053,8 @@ def truncate_line(line: str, max_width: int, *, tab_width: int = 4) -> str:
     :param max_width: the maximum display width the resulting string is allowed to have
     :param tab_width: any tabs in the text will be replaced with this many spaces
     :return: line that has a display width less than or equal to width
-    :raises: ValueError if text contains an unprintable character like a newline
-    :raises: ValueError if max_width is less than 1
+    :raises ValueError: if text contains an unprintable character like a newline
+    :raises ValueError: if max_width is less than 1
     """
     import io
 
@@ -1156,17 +1152,18 @@ def categorize(func: Union[Callable[..., Any], Iterable[Callable[..., Any]]], ca
     :param func: function or list of functions to categorize
     :param category: category to put it in
 
-    :Example:
+    Example:
 
-    >>> import cmd2
-    >>> class MyApp(cmd2.Cmd):
-    >>>   def do_echo(self, arglist):
-    >>>     self.poutput(' '.join(arglist)
-    >>>
-    >>>   cmd2.utils.categorize(do_echo, "Text Processing")
+    ```py
+    import cmd2
+    class MyApp(cmd2.Cmd):
+      def do_echo(self, arglist):
+        self.poutput(' '.join(arglist)
 
-    For an alternative approach to categorizing commands using a decorator, see
-    :func:`~cmd2.decorators.with_category`
+      cmd2.utils.categorize(do_echo, "Text Processing")
+    ```
+
+    For an alternative approach to categorizing commands using a decorator, see [cmd2.decorators.with_category][]
     """
     if isinstance(func, Iterable):
         for item in func:
