@@ -3,29 +3,26 @@
 """
 Unit testing for cmd2/utils.py module.
 """
+
 import os
 import signal
 import sys
 import time
+from unittest import (
+    mock,
+)
 
 import pytest
 
 import cmd2.utils as cu
 from cmd2 import (
     ansi,
+    constants,
 )
 from cmd2.constants import (
     HORIZONTAL_ELLIPSIS,
 )
 
-try:
-    import mock
-except ImportError:
-    from unittest import (
-        mock,
-    )
-
-
 HELLO_WORLD = 'Hello, world!'
 
 
@@ -293,16 +290,10 @@ def pr_none():
 def test_proc_reader_send_sigint(pr_none):
     assert pr_none._proc.poll() is None
     pr_none.send_sigint()
-
-    wait_start = time.monotonic()
     pr_none.wait()
-    wait_finish = time.monotonic()
-
-    # Make sure the process exited before sleep of 5 seconds finished
-    # 3 seconds accounts for some delay but is long enough for the process to exit
-    assert wait_finish - wait_start < 3
-
     ret_code = pr_none._proc.poll()
+
+    # Make sure a SIGINT killed the process
     if sys.platform.startswith('win'):
         assert ret_code is not None
     else:
@@ -634,7 +625,9 @@ def test_align_text_term_width():
     text = 'foo'
     fill_char = ' '
 
-    term_width = shutil.get_terminal_size().columns
+    # Prior to Python 3.11 this can return 0, so use a fallback, so
+    # use the same fallback that cu.align_text() does if needed.
+    term_width = shutil.get_terminal_size().columns or constants.DEFAULT_TERMINAL_WIDTH
     expected_fill = (term_width - ansi.style_aware_wcswidth(text)) * fill_char
 
     aligned = cu.align_text(text, cu.TextAlignment.LEFT, fill_char=fill_char)
@@ -877,3 +870,35 @@ def test_find_editor_not_specified():
     with mock.patch.dict(os.environ, {'PATH': 'fake_dir'}, clear=True):
         editor = cu.find_editor()
     assert editor is None
+
+
+def test_similarity():
+    suggested_command = cu.suggest_similar("comand", ["command", "UNRELATED", "NOT_SIMILAR"])
+    assert suggested_command == "command"
+    suggested_command = cu.suggest_similar("command", ["COMMAND", "acommands"])
+    assert suggested_command == "COMMAND"
+
+
+def test_similarity_without_good_canididates():
+    suggested_command = cu.suggest_similar("comand", ["UNRELATED", "NOT_SIMILAR"])
+    assert suggested_command is None
+    suggested_command = cu.suggest_similar("comand", [])
+    assert suggested_command is None
+
+
+def test_similarity_overwrite_function():
+    options = ["history", "test"]
+    suggested_command = cu.suggest_similar("test", options)
+    assert suggested_command == 'test'
+
+    def custom_similarity_function(s1, s2):
+        return 1.0 if 'history' in (s1, s2) else 0.0
+
+    suggested_command = cu.suggest_similar("test", options, similarity_function_to_use=custom_similarity_function)
+    assert suggested_command == 'history'
+
+    suggested_command = cu.suggest_similar("history", options, similarity_function_to_use=custom_similarity_function)
+    assert suggested_command == 'history'
+
+    suggested_command = cu.suggest_similar("test", ["test"], similarity_function_to_use=custom_similarity_function)
+    assert suggested_command is None
